diff --git a/bank-feeds/.speakeasy/gen.lock b/bank-feeds/.speakeasy/gen.lock
new file mode 100755
index 000000000..70b0cf096
--- /dev/null
+++ b/bank-feeds/.speakeasy/gen.lock
@@ -0,0 +1,192 @@
+lockVersion: 2.0.0
+id: 07093ad1-99d8-4bbd-a29c-a624e1b0e25a
+management:
+ docChecksum: b095b0a347cf654b362ab0929e984eb2
+ docVersion: 3.0.0
+ speakeasyVersion: internal
+ generationVersion: 2.228.3
+ releaseVersion: 6.0.0
+ configChecksum: 3eb45974c86db9d25e88242a656ed13a
+ repoURL: https://github.com/codatio/client-sdk-python.git
+ repoSubDirectory: bank-feeds
+ installationURL: https://github.com/codatio/client-sdk-python.git#subdirectory=bank-feeds
+ published: true
+features:
+ python:
+ constsAndDefaults: 0.1.2
+ core: 4.4.1
+ deprecations: 2.81.1
+ examples: 2.81.3
+ globalSecurity: 2.83.1
+ globalServerURLs: 2.82.1
+ nameOverrides: 2.81.1
+ retries: 2.82.0
+generatedFiles:
+ - src/codatbankfeeds/sdkconfiguration.py
+ - src/codatbankfeeds/companies.py
+ - src/codatbankfeeds/connections.py
+ - src/codatbankfeeds/account_mapping.py
+ - src/codatbankfeeds/source_accounts.py
+ - src/codatbankfeeds/transactions.py
+ - src/codatbankfeeds/sdk.py
+ - pylintrc
+ - setup.py
+ - src/codatbankfeeds/__init__.py
+ - src/codatbankfeeds/utils/__init__.py
+ - src/codatbankfeeds/utils/retries.py
+ - src/codatbankfeeds/utils/utils.py
+ - src/codatbankfeeds/models/errors/sdkerror.py
+ - tests/helpers.py
+ - src/codatbankfeeds/models/operations/create_company.py
+ - src/codatbankfeeds/models/operations/delete_company.py
+ - src/codatbankfeeds/models/operations/get_company.py
+ - src/codatbankfeeds/models/operations/list_companies.py
+ - src/codatbankfeeds/models/operations/update_company.py
+ - src/codatbankfeeds/models/operations/create_connection.py
+ - src/codatbankfeeds/models/operations/delete_connection.py
+ - src/codatbankfeeds/models/operations/get_connection.py
+ - src/codatbankfeeds/models/operations/list_connections.py
+ - src/codatbankfeeds/models/operations/unlink_connection.py
+ - src/codatbankfeeds/models/operations/create_bank_account_mapping.py
+ - src/codatbankfeeds/models/operations/get_bank_account_mapping.py
+ - src/codatbankfeeds/models/operations/create_source_account.py
+ - src/codatbankfeeds/models/operations/delete_source_account.py
+ - src/codatbankfeeds/models/operations/delete_bank_feed_credentials.py
+ - src/codatbankfeeds/models/operations/generate_credentials.py
+ - src/codatbankfeeds/models/operations/list_source_accounts.py
+ - src/codatbankfeeds/models/operations/update_source_account.py
+ - src/codatbankfeeds/models/operations/create_bank_transactions.py
+ - src/codatbankfeeds/models/operations/get_create_operation.py
+ - src/codatbankfeeds/models/operations/list_create_operations.py
+ - src/codatbankfeeds/models/shared/zero.py
+ - src/codatbankfeeds/models/shared/company.py
+ - src/codatbankfeeds/models/shared/connection.py
+ - src/codatbankfeeds/models/shared/dataconnectionstatus.py
+ - src/codatbankfeeds/models/shared/dataconnectionerror.py
+ - src/codatbankfeeds/models/shared/companyrequestbody.py
+ - src/codatbankfeeds/models/shared/items.py
+ - src/codatbankfeeds/models/shared/companies.py
+ - src/codatbankfeeds/models/shared/links.py
+ - src/codatbankfeeds/models/shared/halref.py
+ - src/codatbankfeeds/models/shared/connections.py
+ - src/codatbankfeeds/models/shared/bankfeedaccountmappingresponse.py
+ - src/codatbankfeeds/models/shared/bankfeedmapping.py
+ - src/codatbankfeeds/models/shared/targetaccountoption.py
+ - src/codatbankfeeds/models/shared/sourceaccount.py
+ - src/codatbankfeeds/models/shared/bankaccountcredentials.py
+ - src/codatbankfeeds/models/shared/createbanktransactionsresponse.py
+ - src/codatbankfeeds/models/shared/validation.py
+ - src/codatbankfeeds/models/shared/validationitem.py
+ - src/codatbankfeeds/models/shared/pushoperationstatus.py
+ - src/codatbankfeeds/models/shared/datatype.py
+ - src/codatbankfeeds/models/shared/createbanktransactions.py
+ - src/codatbankfeeds/models/shared/banktransactions.py
+ - src/codatbankfeeds/models/shared/pushoperationchange.py
+ - src/codatbankfeeds/models/shared/pushchangetype.py
+ - src/codatbankfeeds/models/shared/pushoperationref.py
+ - src/codatbankfeeds/models/shared/pushoperation.py
+ - src/codatbankfeeds/models/shared/pushoperations.py
+ - src/codatbankfeeds/models/shared/security.py
+ - src/codatbankfeeds/models/shared/clientratelimitreachedwebhook.py
+ - src/codatbankfeeds/models/shared/clientratelimitreachedwebhookdata.py
+ - src/codatbankfeeds/models/shared/clientratelimitresetwebhook.py
+ - src/codatbankfeeds/models/shared/clientratelimitresetwebhookdata.py
+ - src/codatbankfeeds/models/errors/errormessage.py
+ - src/codatbankfeeds/models/webhooks/client_rate_limit_reached.py
+ - src/codatbankfeeds/models/webhooks/client_rate_limit_reset.py
+ - src/codatbankfeeds/models/__init__.py
+ - src/codatbankfeeds/models/errors/__init__.py
+ - src/codatbankfeeds/models/operations/__init__.py
+ - src/codatbankfeeds/models/shared/__init__.py
+ - src/codatbankfeeds/models/webhooks/__init__.py
+ - docs/models/operations/createcompanyresponse.md
+ - docs/models/operations/deletecompanyrequest.md
+ - docs/models/operations/deletecompanyresponse.md
+ - docs/models/operations/getcompanyrequest.md
+ - docs/models/operations/getcompanyresponse.md
+ - docs/models/operations/listcompaniesrequest.md
+ - docs/models/operations/listcompaniesresponse.md
+ - docs/models/operations/updatecompanyrequest.md
+ - docs/models/operations/updatecompanyresponse.md
+ - docs/models/operations/createconnectionrequestbody.md
+ - docs/models/operations/createconnectionrequest.md
+ - docs/models/operations/createconnectionresponse.md
+ - docs/models/operations/deleteconnectionrequest.md
+ - docs/models/operations/deleteconnectionresponse.md
+ - docs/models/operations/getconnectionrequest.md
+ - docs/models/operations/getconnectionresponse.md
+ - docs/models/operations/listconnectionsrequest.md
+ - docs/models/operations/listconnectionsresponse.md
+ - docs/models/operations/unlinkconnectionupdateconnection.md
+ - docs/models/operations/unlinkconnectionrequest.md
+ - docs/models/operations/unlinkconnectionresponse.md
+ - docs/models/operations/createbankaccountmappingrequest.md
+ - docs/models/operations/createbankaccountmappingresponse.md
+ - docs/models/operations/getbankaccountmappingrequest.md
+ - docs/models/operations/getbankaccountmappingresponse.md
+ - docs/models/operations/createsourceaccountrequest.md
+ - docs/models/operations/createsourceaccountresponse.md
+ - docs/models/operations/deletesourceaccountrequest.md
+ - docs/models/operations/deletesourceaccountresponse.md
+ - docs/models/operations/deletebankfeedcredentialsrequest.md
+ - docs/models/operations/deletebankfeedcredentialsresponse.md
+ - docs/models/operations/generatecredentialsrequest.md
+ - docs/models/operations/generatecredentialsresponse.md
+ - docs/models/operations/listsourceaccountsrequest.md
+ - docs/models/operations/listsourceaccountsresponse.md
+ - docs/models/operations/updatesourceaccountrequest.md
+ - docs/models/operations/updatesourceaccountresponse.md
+ - docs/models/operations/createbanktransactionsrequest.md
+ - docs/models/operations/createbanktransactionsresponse.md
+ - docs/models/operations/getcreateoperationrequest.md
+ - docs/models/operations/getcreateoperationresponse.md
+ - docs/models/operations/listcreateoperationsrequest.md
+ - docs/models/operations/listcreateoperationsresponse.md
+ - docs/models/shared/zero.md
+ - docs/models/shared/groupreference.md
+ - docs/models/shared/company.md
+ - docs/models/shared/sourcetype.md
+ - docs/models/shared/connection.md
+ - docs/models/shared/dataconnectionstatus.md
+ - docs/models/shared/dataconnectionerror.md
+ - docs/models/shared/companyrequestbody.md
+ - docs/models/shared/items.md
+ - docs/models/shared/companies.md
+ - docs/models/shared/links.md
+ - docs/models/shared/halref.md
+ - docs/models/shared/connections.md
+ - docs/models/shared/bankfeedaccountmappingresponse.md
+ - docs/models/shared/bankfeedmapping.md
+ - docs/models/shared/targetaccountoption.md
+ - docs/models/shared/sourceaccount.md
+ - docs/models/shared/bankaccountcredentials.md
+ - docs/models/shared/createbanktransactionsresponse.md
+ - docs/models/shared/validation.md
+ - docs/models/shared/validationitem.md
+ - docs/models/shared/pushoperationstatus.md
+ - docs/models/shared/datatype.md
+ - docs/models/shared/createbanktransactions.md
+ - docs/models/shared/banktransactiontype.md
+ - docs/models/shared/banktransactions.md
+ - docs/models/shared/pushoperationchange.md
+ - docs/models/shared/pushchangetype.md
+ - docs/models/shared/pushoperationref.md
+ - docs/models/shared/pushoperation.md
+ - docs/models/shared/pushoperations.md
+ - docs/models/shared/security.md
+ - docs/models/shared/clientratelimitreachedwebhook.md
+ - docs/models/shared/clientratelimitreachedwebhookdata.md
+ - docs/models/shared/clientratelimitresetwebhook.md
+ - docs/models/shared/clientratelimitresetwebhookdata.md
+ - docs/models/errors/errormessage.md
+ - docs/models/webhooks/clientratelimitreachedresponse.md
+ - docs/models/webhooks/clientratelimitresetresponse.md
+ - docs/sdks/codatbankfeeds/README.md
+ - docs/models/utils/retryconfig.md
+ - docs/sdks/companies/README.md
+ - docs/sdks/connections/README.md
+ - docs/sdks/accountmapping/README.md
+ - docs/sdks/sourceaccounts/README.md
+ - docs/sdks/transactions/README.md
+ - USAGE.md
+ - .gitattributes
diff --git a/bank-feeds/README.md b/bank-feeds/README.md
index 86852e120..1c3fa159e 100755
--- a/bank-feeds/README.md
+++ b/bank-feeds/README.md
@@ -30,6 +30,11 @@ s = codatbankfeeds.CodatBankFeeds(
req = shared.CompanyRequestBody(
description='Requested early access to the new financing scheme.',
+ groups=[
+ shared.Items(
+ id='60d2fa12-8a04-11ee-b9d1-0242ac120002',
+ ),
+ ],
name='Bank of Dave',
)
@@ -104,6 +109,11 @@ s = codatbankfeeds.CodatBankFeeds(
req = shared.CompanyRequestBody(
description='Requested early access to the new financing scheme.',
+ groups=[
+ shared.Items(
+ id='60d2fa12-8a04-11ee-b9d1-0242ac120002',
+ ),
+ ],
name='Bank of Dave',
)
@@ -130,6 +140,11 @@ s = codatbankfeeds.CodatBankFeeds(
req = shared.CompanyRequestBody(
description='Requested early access to the new financing scheme.',
+ groups=[
+ shared.Items(
+ id='60d2fa12-8a04-11ee-b9d1-0242ac120002',
+ ),
+ ],
name='Bank of Dave',
)
@@ -151,7 +166,7 @@ Handling errors in this SDK should largely match your expectations. All operati
| Error Object | Status Code | Content Type |
| --------------------------- | --------------------------- | --------------------------- |
| errors.ErrorMessage | 400,401,402,403,429,500,503 | application/json |
-| errors.SDKError | 400-600 | */* |
+| errors.SDKError | 4x-5xx | */* |
### Example
@@ -167,6 +182,11 @@ s = codatbankfeeds.CodatBankFeeds(
req = shared.CompanyRequestBody(
description='Requested early access to the new financing scheme.',
+ groups=[
+ shared.Items(
+ id='60d2fa12-8a04-11ee-b9d1-0242ac120002',
+ ),
+ ],
name='Bank of Dave',
)
@@ -214,6 +234,11 @@ s = codatbankfeeds.CodatBankFeeds(
req = shared.CompanyRequestBody(
description='Requested early access to the new financing scheme.',
+ groups=[
+ shared.Items(
+ id='60d2fa12-8a04-11ee-b9d1-0242ac120002',
+ ),
+ ],
name='Bank of Dave',
)
@@ -241,6 +266,11 @@ s = codatbankfeeds.CodatBankFeeds(
req = shared.CompanyRequestBody(
description='Requested early access to the new financing scheme.',
+ groups=[
+ shared.Items(
+ id='60d2fa12-8a04-11ee-b9d1-0242ac120002',
+ ),
+ ],
name='Bank of Dave',
)
@@ -257,7 +287,7 @@ if res.company is not None:
## Custom HTTP Client
-The Python SDK makes API calls using the (requests)[https://pypi.org/project/requests/] HTTP library. In order to provide a convenient way to configure timeouts, cookies, proxies, custom headers, and other low-level configuration, you can initialize the SDK client with a custom `requests.Session` object.
+The Python SDK makes API calls using the [requests](https://pypi.org/project/requests/) HTTP library. In order to provide a convenient way to configure timeouts, cookies, proxies, custom headers, and other low-level configuration, you can initialize the SDK client with a custom `requests.Session` object.
For example, you could specify a header for every request that this sdk makes as follows:
```python
@@ -296,6 +326,11 @@ s = codatbankfeeds.CodatBankFeeds(
req = shared.CompanyRequestBody(
description='Requested early access to the new financing scheme.',
+ groups=[
+ shared.Items(
+ id='60d2fa12-8a04-11ee-b9d1-0242ac120002',
+ ),
+ ],
name='Bank of Dave',
)
diff --git a/bank-feeds/RELEASES.md b/bank-feeds/RELEASES.md
index 21b447a7c..60dafc2bb 100644
--- a/bank-feeds/RELEASES.md
+++ b/bank-feeds/RELEASES.md
@@ -748,4 +748,14 @@ Based on:
### Generated
- [python v5.1.0] bank-feeds
### Releases
-- [PyPI v5.1.0] https://pypi.org/project/codat-bankfeeds/5.1.0 - bank-feeds
\ No newline at end of file
+- [PyPI v5.1.0] https://pypi.org/project/codat-bankfeeds/5.1.0 - bank-feeds
+
+## 2024-01-08 13:12:04
+### Changes
+Based on:
+- OpenAPI Doc 3.0.0 https://raw.githubusercontent.com/codatio/oas/main/yaml/Codat-Bank-Feeds.yaml
+- Speakeasy CLI 1.133.2 (2.228.3) https://github.com/speakeasy-api/speakeasy
+### Generated
+- [python v6.0.0] bank-feeds
+### Releases
+- [PyPI v6.0.0] https://pypi.org/project/codat-bankfeeds/6.0.0 - bank-feeds
\ No newline at end of file
diff --git a/bank-feeds/USAGE.md b/bank-feeds/USAGE.md
index cbb72b58f..33001941c 100644
--- a/bank-feeds/USAGE.md
+++ b/bank-feeds/USAGE.md
@@ -11,6 +11,11 @@ s = codatbankfeeds.CodatBankFeeds(
req = shared.CompanyRequestBody(
description='Requested early access to the new financing scheme.',
+ groups=[
+ shared.Items(
+ id='60d2fa12-8a04-11ee-b9d1-0242ac120002',
+ ),
+ ],
name='Bank of Dave',
)
diff --git a/bank-feeds/docs/models/operations/listsourceaccountsresponse.md b/bank-feeds/docs/models/operations/listsourceaccountsresponse.md
index 36c9e1501..215bde744 100644
--- a/bank-feeds/docs/models/operations/listsourceaccountsresponse.md
+++ b/bank-feeds/docs/models/operations/listsourceaccountsresponse.md
@@ -6,6 +6,6 @@
| Field | Type | Required | Description |
| ------------------------------------------------------------------------------------- | ------------------------------------------------------------------------------------- | ------------------------------------------------------------------------------------- | ------------------------------------------------------------------------------------- |
| `content_type` | *str* | :heavy_check_mark: | HTTP response content type for this operation |
-| `source_account` | [Optional[shared.SourceAccount]](../../models/shared/sourceaccount.md) | :heavy_minus_sign: | Success |
| `status_code` | *int* | :heavy_check_mark: | HTTP response status code for this operation |
-| `raw_response` | [requests.Response](https://requests.readthedocs.io/en/latest/api/#requests.Response) | :heavy_check_mark: | Raw HTTP response; suitable for custom response parsing |
\ No newline at end of file
+| `raw_response` | [requests.Response](https://requests.readthedocs.io/en/latest/api/#requests.Response) | :heavy_check_mark: | Raw HTTP response; suitable for custom response parsing |
+| `source_accounts` | List[[shared.SourceAccount](../../models/shared/sourceaccount.md)] | :heavy_minus_sign: | Success |
\ No newline at end of file
diff --git a/bank-feeds/docs/models/shared/company.md b/bank-feeds/docs/models/shared/company.md
index 6d2d39da3..20884c80c 100644
--- a/bank-feeds/docs/models/shared/company.md
+++ b/bank-feeds/docs/models/shared/company.md
@@ -15,6 +15,7 @@ When you create a company, you can specify a `name` and we will automatically ge
| `created_by_user_name` | *Optional[str]* | :heavy_minus_sign: | Name of user that created the company in Codat. | |
| `data_connections` | List[[shared.Connection](../../models/shared/connection.md)] | :heavy_minus_sign: | N/A | |
| `description` | *Optional[str]* | :heavy_minus_sign: | Additional information about the company. This can be used to store foreign IDs, references, etc. | Requested early access to the new financing scheme. |
+| `groups` | List[[shared.GroupReference](../../models/shared/groupreference.md)] | :heavy_minus_sign: | An array of groups the company has been assigned to. | |
| `id` | *str* | :heavy_check_mark: | Unique identifier for your SMB in Codat. | 8a210b68-6988-11ed-a1eb-0242ac120002 |
| `last_sync` | *Optional[str]* | :heavy_minus_sign: | In Codat's data model, dates and times are represented using the ISO 8601 standard. Date and time fields are formatted as strings; for example:
```
2020-10-08T22:40:50Z
2021-01-01T00:00:00
```
When syncing data that contains `DateTime` fields from Codat, make sure you support the following cases when reading time information:
- Coordinated Universal Time (UTC): `2021-11-15T06:00:00Z`
- Unqualified local time: `2021-11-15T01:00:00`
- UTC time offsets: `2021-11-15T01:00:00-05:00`
> Time zones
>
> Not all dates from Codat will contain information about time zones.
> Where it is not available from the underlying platform, Codat will return these as times local to the business whose data has been synced. | 2022-10-23 00:00:00 +0000 UTC |
| `name` | *str* | :heavy_check_mark: | The name of the company | Codat Ltd. |
diff --git a/bank-feeds/docs/models/shared/companyrequestbody.md b/bank-feeds/docs/models/shared/companyrequestbody.md
index 339e136ce..3f5f3de92 100644
--- a/bank-feeds/docs/models/shared/companyrequestbody.md
+++ b/bank-feeds/docs/models/shared/companyrequestbody.md
@@ -6,4 +6,5 @@
| Field | Type | Required | Description | Example |
| ------------------------------------------------------------------------------------------------- | ------------------------------------------------------------------------------------------------- | ------------------------------------------------------------------------------------------------- | ------------------------------------------------------------------------------------------------- | ------------------------------------------------------------------------------------------------- |
| `description` | *Optional[str]* | :heavy_minus_sign: | Additional information about the company. This can be used to store foreign IDs, references, etc. | Requested early access to the new financing scheme. |
+| `groups` | List[[shared.Items](../../models/shared/items.md)] | :heavy_minus_sign: | Reference to the groups that the company is assigned to. | |
| `name` | *str* | :heavy_check_mark: | Name of company being connected. | Bank of Dave |
\ No newline at end of file
diff --git a/bank-feeds/docs/models/shared/groupreference.md b/bank-feeds/docs/models/shared/groupreference.md
new file mode 100644
index 000000000..31666edf4
--- /dev/null
+++ b/bank-feeds/docs/models/shared/groupreference.md
@@ -0,0 +1,8 @@
+# GroupReference
+
+
+## Fields
+
+| Field | Type | Required | Description | Example |
+| ------------------------------------ | ------------------------------------ | ------------------------------------ | ------------------------------------ | ------------------------------------ |
+| `id` | *Optional[str]* | :heavy_minus_sign: | Unique identifier for the group. | 60d2fa12-8a04-11ee-b9d1-0242ac120002 |
\ No newline at end of file
diff --git a/bank-feeds/docs/models/shared/items.md b/bank-feeds/docs/models/shared/items.md
new file mode 100644
index 000000000..8bf62de24
--- /dev/null
+++ b/bank-feeds/docs/models/shared/items.md
@@ -0,0 +1,8 @@
+# Items
+
+
+## Fields
+
+| Field | Type | Required | Description | Example |
+| ------------------------------------ | ------------------------------------ | ------------------------------------ | ------------------------------------ | ------------------------------------ |
+| `id` | *Optional[str]* | :heavy_minus_sign: | Unique identifier for the group. | 60d2fa12-8a04-11ee-b9d1-0242ac120002 |
\ No newline at end of file
diff --git a/bank-feeds/docs/models/shared/sourcetype.md b/bank-feeds/docs/models/shared/sourcetype.md
index e32b27ce4..2daec8ef3 100644
--- a/bank-feeds/docs/models/shared/sourcetype.md
+++ b/bank-feeds/docs/models/shared/sourcetype.md
@@ -9,6 +9,8 @@ The type of platform of the connection.
| ------------ | ------------ |
| `ACCOUNTING` | Accounting |
| `BANKING` | Banking |
+| `BANK_FEED` | BankFeed |
| `COMMERCE` | Commerce |
+| `EXPENSE` | Expense |
| `OTHER` | Other |
| `UNKNOWN` | Unknown |
\ No newline at end of file
diff --git a/bank-feeds/docs/sdks/accountmapping/README.md b/bank-feeds/docs/sdks/accountmapping/README.md
index db54118db..82d48c31c 100644
--- a/bank-feeds/docs/sdks/accountmapping/README.md
+++ b/bank-feeds/docs/sdks/accountmapping/README.md
@@ -63,7 +63,7 @@ if res.bank_feed_account_mapping_response is not None:
| Error Object | Status Code | Content Type |
| ------------------------------- | ------------------------------- | ------------------------------- |
| errors.ErrorMessage | 400,401,402,403,404,429,500,503 | application/json |
-| errors.SDKError | 400-600 | */* |
+| errors.SDKError | 4x-5xx | */* |
## get
@@ -113,4 +113,4 @@ if res.bank_feed_mapping is not None:
| Error Object | Status Code | Content Type |
| --------------------------- | --------------------------- | --------------------------- |
| errors.ErrorMessage | 401,402,403,404,429,500,503 | application/json |
-| errors.SDKError | 400-600 | */* |
+| errors.SDKError | 4x-5xx | */* |
diff --git a/bank-feeds/docs/sdks/companies/README.md b/bank-feeds/docs/sdks/companies/README.md
index ba407178e..f73905db5 100644
--- a/bank-feeds/docs/sdks/companies/README.md
+++ b/bank-feeds/docs/sdks/companies/README.md
@@ -15,11 +15,12 @@ Create and manage your Codat companies.
## create
-Creates a new company that can be used to assign connections to.
-
-If forbidden characters (see `name` pattern) are present in the request, a company will be created with the forbidden characters removed. For example, `Company (Codat[1])` with be created as `Company Codat1`.
+Use the *Create company* endpoint to create a new [company](https://docs.codat.io/bank-feeds-api#/schemas/Company) that represents your customer in Codat.
+A [company](https://docs.codat.io/bank-feeds-api#/schemas/Company) represents a business sharing access to their data.
+Each company can have multiple [connections](https://docs.codat.io/bank-feeds-api#/schemas/Connection) to different data sources, such as one connection to Xero for accounting data, two connections to Plaid for two bank accounts, and a connection to Zettle for POS data.
+If forbidden characters (see `name` pattern) are present in the request, a company will be created with the forbidden characters removed. For example, `Company (Codat[1])` with be created as `Company Codat1`.
### Example Usage
@@ -35,6 +36,11 @@ s = codatbankfeeds.CodatBankFeeds(
req = shared.CompanyRequestBody(
description='Requested early access to the new financing scheme.',
+ groups=[
+ shared.Items(
+ id='60d2fa12-8a04-11ee-b9d1-0242ac120002',
+ ),
+ ],
name='Bank of Dave',
)
@@ -61,12 +67,15 @@ if res.company is not None:
| Error Object | Status Code | Content Type |
| --------------------------- | --------------------------- | --------------------------- |
| errors.ErrorMessage | 400,401,402,403,429,500,503 | application/json |
-| errors.SDKError | 400-600 | */* |
+| errors.SDKError | 4x-5xx | */* |
## delete
-
-Permanently deletes a company, its connections and any cached data. This operation is irreversible. If the company ID does not exist an error is returned.
+The *Delete company* endpoint permanently deletes a [company](https://docs.codat.io/bank-feeds-api#/schemas/Company), its [connections](https://docs.codat.io/bank-feeds-api#/schemas/Connection) and any cached data. This operation is irreversible.
+
+A [company](https://docs.codat.io/bank-feeds-api#/schemas/Company) represents a business sharing access to their data.
+Each company can have multiple [connections](https://docs.codat.io/bank-feeds-api#/schemas/Connection) to different data sources, such as one connection to Xero for accounting data, two connections to Plaid for two bank accounts, and a connection to Zettle for POS data.
+
### Example Usage
@@ -107,11 +116,15 @@ if res.status_code == 200:
| Error Object | Status Code | Content Type |
| --------------------------- | --------------------------- | --------------------------- |
| errors.ErrorMessage | 401,402,403,404,429,500,503 | application/json |
-| errors.SDKError | 400-600 | */* |
+| errors.SDKError | 4x-5xx | */* |
## get
-Returns the company for a valid identifier. If the identifier is for a deleted company, a not found response is returned.
+The *Get company* endpoint returns a single company for a given `companyId`.
+
+A [company](https://docs.codat.io/bank-feeds-api#/schemas/Company) represents a business sharing access to their data.
+Each company can have multiple [connections](https://docs.codat.io/bank-feeds-api#/schemas/Connection) to different data sources, such as one connection to Xero for accounting data, two connections to Plaid for two bank accounts, and a connection to Zettle for POS data.
+
### Example Usage
@@ -152,11 +165,14 @@ if res.company is not None:
| Error Object | Status Code | Content Type |
| --------------------------- | --------------------------- | --------------------------- |
| errors.ErrorMessage | 401,402,403,404,429,500,503 | application/json |
-| errors.SDKError | 400-600 | */* |
+| errors.SDKError | 4x-5xx | */* |
## list
-Returns a list of your companies. The company schema contains a list of [connections](https://docs.codat.io/bank-feeds-api#/schemas/Connection) related to the company.
+The *List companies* endpoint returns a list of [companies] associated to your instances.
+
+A [company](https://docs.codat.io/bank-feeds-api#/schemas/Company) represents a business sharing access to their data.
+Each company can have multiple [connections](https://docs.codat.io/bank-feeds-api#/schemas/Connection) to different data sources, such as one connection to Xero for accounting data, two connections to Plaid for two bank accounts, and a connection to Zettle for POS data.
### Example Usage
@@ -199,11 +215,15 @@ if res.companies is not None:
| Error Object | Status Code | Content Type |
| ------------------------------- | ------------------------------- | ------------------------------- |
| errors.ErrorMessage | 400,401,402,403,404,429,500,503 | application/json |
-| errors.SDKError | 400-600 | */* |
+| errors.SDKError | 4x-5xx | */* |
## update
-Updates both the name and description of the company.
+Use the *Update company* endpoint to update both the name and description of the company.
+If you use [groups](https://docs.codat.io/bank-feeds-api#/schemas/Group) to manage a set of companies, use the [Add company](https://docs.codat.io/bank-feeds-api#/operations/add-company-to-group) or [Remove company](https://docs.codat.io/bank-feeds-api#/operations/remove-company-from-group) endpoints to add or remove a company from a group.
+
+A [company](https://docs.codat.io/bank-feeds-api#/schemas/Company) represents a business sharing access to their data.
+Each company can have multiple [connections](https://docs.codat.io/bank-feeds-api#/schemas/Connection) to different data sources, such as one connection to Xero for accounting data, two connections to Plaid for two bank accounts, and a connection to Zettle for POS data.
### Example Usage
@@ -220,6 +240,11 @@ s = codatbankfeeds.CodatBankFeeds(
req = operations.UpdateCompanyRequest(
company_request_body=shared.CompanyRequestBody(
description='Requested early access to the new financing scheme.',
+ groups=[
+ shared.Items(
+ id='60d2fa12-8a04-11ee-b9d1-0242ac120002',
+ ),
+ ],
name='Bank of Dave',
),
company_id='8a210b68-6988-11ed-a1eb-0242ac120002',
@@ -248,4 +273,4 @@ if res.company is not None:
| Error Object | Status Code | Content Type |
| --------------------------- | --------------------------- | --------------------------- |
| errors.ErrorMessage | 401,402,403,404,429,500,503 | application/json |
-| errors.SDKError | 400-600 | */* |
+| errors.SDKError | 4x-5xx | */* |
diff --git a/bank-feeds/docs/sdks/connections/README.md b/bank-feeds/docs/sdks/connections/README.md
index 295e85d77..61452ab10 100644
--- a/bank-feeds/docs/sdks/connections/README.md
+++ b/bank-feeds/docs/sdks/connections/README.md
@@ -61,7 +61,7 @@ if res.connection is not None:
| Error Object | Status Code | Content Type |
| --------------------------- | --------------------------- | --------------------------- |
| errors.ErrorMessage | 401,402,403,404,429,500,503 | application/json |
-| errors.SDKError | 400-600 | */* |
+| errors.SDKError | 4x-5xx | */* |
## delete
@@ -108,7 +108,7 @@ if res.status_code == 200:
| Error Object | Status Code | Content Type |
| --------------------------- | --------------------------- | --------------------------- |
| errors.ErrorMessage | 401,402,403,404,429,500,503 | application/json |
-| errors.SDKError | 400-600 | */* |
+| errors.SDKError | 4x-5xx | */* |
## get
@@ -154,7 +154,7 @@ if res.connection is not None:
| Error Object | Status Code | Content Type |
| --------------------------- | --------------------------- | --------------------------- |
| errors.ErrorMessage | 401,402,403,404,429,500,503 | application/json |
-| errors.SDKError | 400-600 | */* |
+| errors.SDKError | 4x-5xx | */* |
## list
@@ -202,7 +202,7 @@ if res.connections is not None:
| Error Object | Status Code | Content Type |
| ------------------------------- | ------------------------------- | ------------------------------- |
| errors.ErrorMessage | 400,401,402,403,404,429,500,503 | application/json |
-| errors.SDKError | 400-600 | */* |
+| errors.SDKError | 4x-5xx | */* |
## unlink
@@ -249,4 +249,4 @@ if res.connection is not None:
| Error Object | Status Code | Content Type |
| --------------------------- | --------------------------- | --------------------------- |
| errors.ErrorMessage | 401,402,403,404,429,500,503 | application/json |
-| errors.SDKError | 400-600 | */* |
+| errors.SDKError | 4x-5xx | */* |
diff --git a/bank-feeds/docs/sdks/sourceaccounts/README.md b/bank-feeds/docs/sdks/sourceaccounts/README.md
index 46cc69444..dc4809a66 100644
--- a/bank-feeds/docs/sdks/sourceaccounts/README.md
+++ b/bank-feeds/docs/sdks/sourceaccounts/README.md
@@ -86,7 +86,7 @@ if res.source_account is not None:
| Error Object | Status Code | Content Type |
| ------------------------------- | ------------------------------- | ------------------------------- |
| errors.ErrorMessage | 400,401,402,403,404,429,500,503 | application/json |
-| errors.SDKError | 400-600 | */* |
+| errors.SDKError | 4x-5xx | */* |
## delete
@@ -136,7 +136,7 @@ if res.status_code == 200:
| Error Object | Status Code | Content Type |
| --------------------------- | --------------------------- | --------------------------- |
| errors.ErrorMessage | 401,402,403,404,429,500,503 | application/json |
-| errors.SDKError | 400-600 | */* |
+| errors.SDKError | 4x-5xx | */* |
## delete_credentials
@@ -184,7 +184,7 @@ if res.status_code == 200:
| Error Object | Status Code | Content Type |
| --------------------------- | --------------------------- | --------------------------- |
| errors.ErrorMessage | 401,402,403,404,429,500,503 | application/json |
-| errors.SDKError | 400-600 | */* |
+| errors.SDKError | 4x-5xx | */* |
## generate_credentials
@@ -234,7 +234,7 @@ if res.bank_account_credentials is not None:
| Error Object | Status Code | Content Type |
| --------------------------- | --------------------------- | --------------------------- |
| errors.ErrorMessage | 401,402,403,404,429,500,503 | application/json |
-| errors.SDKError | 400-600 | */* |
+| errors.SDKError | 4x-5xx | */* |
## list
@@ -262,7 +262,7 @@ req = operations.ListSourceAccountsRequest(
res = s.source_accounts.list(req)
-if res.source_account is not None:
+if res.source_accounts is not None:
# handle response
pass
```
@@ -283,7 +283,7 @@ if res.source_account is not None:
| Error Object | Status Code | Content Type |
| --------------------------- | --------------------------- | --------------------------- |
| errors.ErrorMessage | 401,402,403,404,429,500,503 | application/json |
-| errors.SDKError | 400-600 | */* |
+| errors.SDKError | 4x-5xx | */* |
## update
@@ -338,4 +338,4 @@ if res.source_account is not None:
| Error Object | Status Code | Content Type |
| ------------------------------- | ------------------------------- | ------------------------------- |
| errors.ErrorMessage | 400,401,402,403,404,429,500,503 | application/json |
-| errors.SDKError | 400-600 | */* |
+| errors.SDKError | 4x-5xx | */* |
diff --git a/bank-feeds/docs/sdks/transactions/README.md b/bank-feeds/docs/sdks/transactions/README.md
index 9ac8fbb31..35958da77 100644
--- a/bank-feeds/docs/sdks/transactions/README.md
+++ b/bank-feeds/docs/sdks/transactions/README.md
@@ -81,7 +81,7 @@ if res.create_bank_transactions_response is not None:
| Error Object | Status Code | Content Type |
| ------------------------------- | ------------------------------- | ------------------------------- |
| errors.ErrorMessage | 400,401,402,403,404,429,500,503 | application/json |
-| errors.SDKError | 400-600 | */* |
+| errors.SDKError | 4x-5xx | */* |
## get_create_operation
@@ -127,7 +127,7 @@ if res.push_operation is not None:
| Error Object | Status Code | Content Type |
| --------------------------- | --------------------------- | --------------------------- |
| errors.ErrorMessage | 401,402,403,404,429,500,503 | application/json |
-| errors.SDKError | 400-600 | */* |
+| errors.SDKError | 4x-5xx | */* |
## list_create_operations
@@ -175,4 +175,4 @@ if res.push_operations is not None:
| Error Object | Status Code | Content Type |
| ------------------------------- | ------------------------------- | ------------------------------- |
| errors.ErrorMessage | 400,401,402,403,404,429,500,503 | application/json |
-| errors.SDKError | 400-600 | */* |
+| errors.SDKError | 4x-5xx | */* |
diff --git a/bank-feeds/gen.yaml b/bank-feeds/gen.yaml
index b4effadd8..dbed26228 100644
--- a/bank-feeds/gen.yaml
+++ b/bank-feeds/gen.yaml
@@ -1,31 +1,16 @@
-configVersion: 1.0.0
-management:
- docChecksum: a19e6e4f901ace72e0fa1bb907ccb71c
- docVersion: 3.0.0
- speakeasyVersion: 1.126.3
- generationVersion: 2.214.3
+configVersion: 2.0.0
generation:
- comments: {}
sdkClassName: CodatBankFeeds
- repoURL: https://github.com/codatio/client-sdk-python.git
usageSnippets:
optionalPropertyRendering: withExample
+ fixes:
+ nameResolutionDec2023: false
telemetryEnabled: true
-features:
- python:
- core: 4.3.0
- deprecations: 2.81.1
- examples: 2.81.3
- globalSecurity: 2.83.1
- globalServerURLs: 2.82.1
- nameOverrides: 2.81.1
- retries: 2.82.0
python:
- version: 5.1.0
+ version: 6.0.0
author: Codat
clientServerStatusCodesAsErrors: true
- description: Set up bank feeds from accounts in your application to supported accounting
- platforms.
+ description: Set up bank feeds from accounts in your application to supported accounting platforms.
flattenGlobalSecurity: false
imports:
option: openapi
@@ -36,9 +21,6 @@ python:
shared: models/shared
webhooks: models/webhooks
inputModelSuffix: input
- installationURL: https://github.com/codatio/client-sdk-python.git#subdirectory=bank-feeds
maxMethodParams: 0
outputModelSuffix: output
packageName: codat-bankfeeds
- published: true
- repoSubDirectory: bank-feeds
diff --git a/bank-feeds/setup.py b/bank-feeds/setup.py
index 014b39286..e851a8b3f 100644
--- a/bank-feeds/setup.py
+++ b/bank-feeds/setup.py
@@ -10,7 +10,7 @@
setuptools.setup(
name="codat-bankfeeds",
- version="5.1.0",
+ version="6.0.0",
author="Codat",
description="Set up bank feeds from accounts in your application to supported accounting platforms.",
long_description=long_description,
diff --git a/bank-feeds/src/codatbankfeeds/models/operations/list_source_accounts.py b/bank-feeds/src/codatbankfeeds/models/operations/list_source_accounts.py
index 278933f15..f0c67c9f8 100644
--- a/bank-feeds/src/codatbankfeeds/models/operations/list_source_accounts.py
+++ b/bank-feeds/src/codatbankfeeds/models/operations/list_source_accounts.py
@@ -4,7 +4,7 @@
import dataclasses
import requests as requests_http
from ...models.shared import sourceaccount as shared_sourceaccount
-from typing import Optional
+from typing import List, Optional
@dataclasses.dataclass
@@ -25,7 +25,7 @@ class ListSourceAccountsResponse:
r"""Raw HTTP response; suitable for custom response parsing"""
status_code: int = dataclasses.field()
r"""HTTP response status code for this operation"""
- source_account: Optional[shared_sourceaccount.SourceAccount] = dataclasses.field(default=None)
+ source_accounts: Optional[List[shared_sourceaccount.SourceAccount]] = dataclasses.field(default=None)
r"""Success"""
diff --git a/bank-feeds/src/codatbankfeeds/models/shared/__init__.py b/bank-feeds/src/codatbankfeeds/models/shared/__init__.py
index e8311a885..6e4ef051f 100644
--- a/bank-feeds/src/codatbankfeeds/models/shared/__init__.py
+++ b/bank-feeds/src/codatbankfeeds/models/shared/__init__.py
@@ -19,6 +19,7 @@
from .dataconnectionstatus import *
from .datatype import *
from .halref import *
+from .items import *
from .links import *
from .pushchangetype import *
from .pushoperation import *
@@ -33,4 +34,4 @@
from .validationitem import *
from .zero import *
-__all__ = ["BankAccountCredentials","BankFeedAccountMappingResponse","BankFeedMapping","BankTransactionType","BankTransactions","ClientRateLimitReachedWebhook","ClientRateLimitReachedWebhookData","ClientRateLimitResetWebhook","ClientRateLimitResetWebhookData","Companies","Company","CompanyRequestBody","Connection","Connections","CreateBankTransactions","CreateBankTransactionsResponse","DataConnectionError","DataConnectionStatus","DataType","HalRef","Links","PushChangeType","PushOperation","PushOperationChange","PushOperationRef","PushOperationStatus","PushOperations","Security","SourceAccount","SourceType","TargetAccountOption","Validation","ValidationItem","Zero"]
+__all__ = ["BankAccountCredentials","BankFeedAccountMappingResponse","BankFeedMapping","BankTransactionType","BankTransactions","ClientRateLimitReachedWebhook","ClientRateLimitReachedWebhookData","ClientRateLimitResetWebhook","ClientRateLimitResetWebhookData","Companies","Company","CompanyRequestBody","Connection","Connections","CreateBankTransactions","CreateBankTransactionsResponse","DataConnectionError","DataConnectionStatus","DataType","GroupReference","HalRef","Items","Links","PushChangeType","PushOperation","PushOperationChange","PushOperationRef","PushOperationStatus","PushOperations","Security","SourceAccount","SourceType","TargetAccountOption","Validation","ValidationItem","Zero"]
diff --git a/bank-feeds/src/codatbankfeeds/models/shared/company.py b/bank-feeds/src/codatbankfeeds/models/shared/company.py
index 7901af5dd..ac9ed67f9 100644
--- a/bank-feeds/src/codatbankfeeds/models/shared/company.py
+++ b/bank-feeds/src/codatbankfeeds/models/shared/company.py
@@ -8,6 +8,15 @@
from typing import List, Optional
+@dataclass_json(undefined=Undefined.EXCLUDE)
+@dataclasses.dataclass
+class GroupReference:
+ id: Optional[str] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('id'), 'exclude': lambda f: f is None }})
+ r"""Unique identifier for the group."""
+
+
+
+
@dataclass_json(undefined=Undefined.EXCLUDE)
@dataclasses.dataclass
class Company:
@@ -49,6 +58,8 @@ class Company:
data_connections: Optional[List[Connection]] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('dataConnections'), 'exclude': lambda f: f is None }})
description: Optional[str] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('description'), 'exclude': lambda f: f is None }})
r"""Additional information about the company. This can be used to store foreign IDs, references, etc."""
+ groups: Optional[List[GroupReference]] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('groups'), 'exclude': lambda f: f is None }})
+ r"""An array of groups the company has been assigned to."""
last_sync: Optional[str] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('lastSync'), 'exclude': lambda f: f is None }})
r"""In Codat's data model, dates and times are represented using the ISO 8601 standard. Date and time fields are formatted as strings; for example:
diff --git a/bank-feeds/src/codatbankfeeds/models/shared/companyrequestbody.py b/bank-feeds/src/codatbankfeeds/models/shared/companyrequestbody.py
index 9610fab83..79b8e2a22 100644
--- a/bank-feeds/src/codatbankfeeds/models/shared/companyrequestbody.py
+++ b/bank-feeds/src/codatbankfeeds/models/shared/companyrequestbody.py
@@ -2,9 +2,10 @@
from __future__ import annotations
import dataclasses
+from .items import Items
from codatbankfeeds import utils
from dataclasses_json import Undefined, dataclass_json
-from typing import Optional
+from typing import List, Optional
@dataclass_json(undefined=Undefined.EXCLUDE)
@@ -14,5 +15,7 @@ class CompanyRequestBody:
r"""Name of company being connected."""
description: Optional[str] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('description'), 'exclude': lambda f: f is None }})
r"""Additional information about the company. This can be used to store foreign IDs, references, etc."""
+ groups: Optional[List[Items]] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('groups'), 'exclude': lambda f: f is None }})
+ r"""Reference to the groups that the company is assigned to."""
diff --git a/bank-feeds/src/codatbankfeeds/models/shared/connection.py b/bank-feeds/src/codatbankfeeds/models/shared/connection.py
index 55327060f..e8caf95cf 100644
--- a/bank-feeds/src/codatbankfeeds/models/shared/connection.py
+++ b/bank-feeds/src/codatbankfeeds/models/shared/connection.py
@@ -13,7 +13,9 @@ class SourceType(str, Enum):
r"""The type of platform of the connection."""
ACCOUNTING = 'Accounting'
BANKING = 'Banking'
+ BANK_FEED = 'BankFeed'
COMMERCE = 'Commerce'
+ EXPENSE = 'Expense'
OTHER = 'Other'
UNKNOWN = 'Unknown'
diff --git a/bank-feeds/src/codatbankfeeds/models/shared/items.py b/bank-feeds/src/codatbankfeeds/models/shared/items.py
new file mode 100644
index 000000000..fdc4168dd
--- /dev/null
+++ b/bank-feeds/src/codatbankfeeds/models/shared/items.py
@@ -0,0 +1,16 @@
+"""Code generated by Speakeasy (https://speakeasyapi.dev). DO NOT EDIT."""
+
+from __future__ import annotations
+import dataclasses
+from codatbankfeeds import utils
+from dataclasses_json import Undefined, dataclass_json
+from typing import Optional
+
+
+@dataclass_json(undefined=Undefined.EXCLUDE)
+@dataclasses.dataclass
+class Items:
+ id: Optional[str] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('id'), 'exclude': lambda f: f is None }})
+ r"""Unique identifier for the group."""
+
+
diff --git a/bank-feeds/src/codatbankfeeds/sdkconfiguration.py b/bank-feeds/src/codatbankfeeds/sdkconfiguration.py
index fa6e9bb23..8d151c705 100644
--- a/bank-feeds/src/codatbankfeeds/sdkconfiguration.py
+++ b/bank-feeds/src/codatbankfeeds/sdkconfiguration.py
@@ -22,9 +22,9 @@ class SDKConfiguration:
server_idx: int = 0
language: str = 'python'
openapi_doc_version: str = '3.0.0'
- sdk_version: str = '5.1.0'
- gen_version: str = '2.214.3'
- user_agent: str = 'speakeasy-sdk/python 5.1.0 2.214.3 3.0.0 codat-bankfeeds'
+ sdk_version: str = '6.0.0'
+ gen_version: str = '2.228.3'
+ user_agent: str = 'speakeasy-sdk/python 6.0.0 2.228.3 3.0.0 codat-bankfeeds'
retry_config: RetryConfig = None
def get_server_details(self) -> Tuple[str, Dict[str, str]]:
diff --git a/bank-feeds/src/codatbankfeeds/source_accounts.py b/bank-feeds/src/codatbankfeeds/source_accounts.py
index fbd7cb918..f186d5798 100644
--- a/bank-feeds/src/codatbankfeeds/source_accounts.py
+++ b/bank-feeds/src/codatbankfeeds/source_accounts.py
@@ -3,7 +3,7 @@
from .sdkconfiguration import SDKConfiguration
from codatbankfeeds import utils
from codatbankfeeds.models import errors, operations, shared
-from typing import Optional
+from typing import List, Optional
class SourceAccounts:
r"""Source accounts act as a bridge to bank accounts in accounting software."""
@@ -305,8 +305,8 @@ def do_request():
if http_res.status_code == 200:
if utils.match_content_type(content_type, 'application/json'):
- out = utils.unmarshal_json(http_res.text, Optional[shared.SourceAccount])
- res.source_account = out
+ out = utils.unmarshal_json(http_res.text, Optional[List[shared.SourceAccount]])
+ res.source_accounts = out
else:
raise errors.SDKError(f'unknown content-type received: {content_type}', http_res.status_code, http_res.text, http_res)
elif http_res.status_code in [401, 402, 403, 404, 429, 500, 503]:
diff --git a/bank-feeds/src/codatbankfeeds/companies.py b/bank-feeds/src/codatbankfeeds/companies.py
index 4e750b407..18f573d15 100644
--- a/bank-feeds/src/codatbankfeeds/companies.py
+++ b/bank-feeds/src/codatbankfeeds/companies.py
@@ -16,7 +16,10 @@ def __init__(self, sdk_config: SDKConfiguration) -> None:
def create(self, request: Optional[shared.CompanyRequestBody], retries: Optional[utils.RetryConfig] = None) -> operations.CreateCompanyResponse:
r"""Create company
- Creates a new company that can be used to assign connections to.
+ Use the *Create company* endpoint to create a new [company](https://docs.codat.io/bank-feeds-api#/schemas/Company) that represents your customer in Codat.
+
+ A [company](https://docs.codat.io/bank-feeds-api#/schemas/Company) represents a business sharing access to their data.
+ Each company can have multiple [connections](https://docs.codat.io/bank-feeds-api#/schemas/Connection) to different data sources, such as one connection to Xero for accounting data, two connections to Plaid for two bank accounts, and a connection to Zettle for POS data.
If forbidden characters (see `name` pattern) are present in the request, a company will be created with the forbidden characters removed. For example, `Company (Codat[1])` with be created as `Company Codat1`.
"""
@@ -77,7 +80,10 @@ def do_request():
def delete(self, request: operations.DeleteCompanyRequest, retries: Optional[utils.RetryConfig] = None) -> operations.DeleteCompanyResponse:
r"""Delete a company
- Permanently deletes a company, its connections and any cached data. This operation is irreversible. If the company ID does not exist an error is returned.
+ The *Delete company* endpoint permanently deletes a [company](https://docs.codat.io/bank-feeds-api#/schemas/Company), its [connections](https://docs.codat.io/bank-feeds-api#/schemas/Connection) and any cached data. This operation is irreversible.
+
+ A [company](https://docs.codat.io/bank-feeds-api#/schemas/Company) represents a business sharing access to their data.
+ Each company can have multiple [connections](https://docs.codat.io/bank-feeds-api#/schemas/Connection) to different data sources, such as one connection to Xero for accounting data, two connections to Plaid for two bank accounts, and a connection to Zettle for POS data.
"""
base_url = utils.template_url(*self.sdk_configuration.get_server_details())
@@ -129,7 +135,10 @@ def do_request():
def get(self, request: operations.GetCompanyRequest, retries: Optional[utils.RetryConfig] = None) -> operations.GetCompanyResponse:
r"""Get company
- Returns the company for a valid identifier. If the identifier is for a deleted company, a not found response is returned.
+ The *Get company* endpoint returns a single company for a given `companyId`.
+
+ A [company](https://docs.codat.io/bank-feeds-api#/schemas/Company) represents a business sharing access to their data.
+ Each company can have multiple [connections](https://docs.codat.io/bank-feeds-api#/schemas/Connection) to different data sources, such as one connection to Xero for accounting data, two connections to Plaid for two bank accounts, and a connection to Zettle for POS data.
"""
base_url = utils.template_url(*self.sdk_configuration.get_server_details())
@@ -185,7 +194,10 @@ def do_request():
def list(self, request: operations.ListCompaniesRequest, retries: Optional[utils.RetryConfig] = None) -> operations.ListCompaniesResponse:
r"""List companies
- Returns a list of your companies. The company schema contains a list of [connections](https://docs.codat.io/bank-feeds-api#/schemas/Connection) related to the company.
+ The *List companies* endpoint returns a list of [companies] associated to your instances.
+
+ A [company](https://docs.codat.io/bank-feeds-api#/schemas/Company) represents a business sharing access to their data.
+ Each company can have multiple [connections](https://docs.codat.io/bank-feeds-api#/schemas/Connection) to different data sources, such as one connection to Xero for accounting data, two connections to Plaid for two bank accounts, and a connection to Zettle for POS data.
"""
base_url = utils.template_url(*self.sdk_configuration.get_server_details())
@@ -242,7 +254,11 @@ def do_request():
def update(self, request: operations.UpdateCompanyRequest, retries: Optional[utils.RetryConfig] = None) -> operations.UpdateCompanyResponse:
r"""Update company
- Updates both the name and description of the company.
+ Use the *Update company* endpoint to update both the name and description of the company.
+ If you use [groups](https://docs.codat.io/bank-feeds-api#/schemas/Group) to manage a set of companies, use the [Add company](https://docs.codat.io/bank-feeds-api#/operations/add-company-to-group) or [Remove company](https://docs.codat.io/bank-feeds-api#/operations/remove-company-from-group) endpoints to add or remove a company from a group.
+
+ A [company](https://docs.codat.io/bank-feeds-api#/schemas/Company) represents a business sharing access to their data.
+ Each company can have multiple [connections](https://docs.codat.io/bank-feeds-api#/schemas/Connection) to different data sources, such as one connection to Xero for accounting data, two connections to Plaid for two bank accounts, and a connection to Zettle for POS data.
"""
base_url = utils.template_url(*self.sdk_configuration.get_server_details())